@@ -8,7 +8,7 @@
 
 #include <QObject>
 
-#include <KWayland/Client/kwaylandclient_export.h>
+#include "KWayland/Client/kwaylandclient_export.h"
 
 struct org_kde_plasma_virtual_desktop_management;
 struct org_kde_plasma_virtual_desktop;
@@ -17,7 +17,6 @@ namespace KWayland
 {
 namespace Client
 {
-
 class EventQueue;
 class PlasmaVirtualDesktop;
 
@@ -56,7 +55,7 @@ public:
      * Registry::createPlasmaVirtualDesktopManagement.
      **/
     explicit PlasmaVirtualDesktopManagement(QObject *parent = nullptr);
-    virtual ~PlasmaVirtualDesktopManagement();
+    ~PlasmaVirtualDesktopManagement() override;
 
     /**
      * Setup this PlasmaVirtualDesktopManagement to manage the @p plasmavirtualdesktopmanagement.
@@ -127,7 +126,7 @@ public:
     /**
      * @returns All the existent virtual desktops
      */
-    QList <PlasmaVirtualDesktop *> desktops() const;
+    QList<PlasmaVirtualDesktop *> desktops() const;
 
     /**
      * @returns How many rows the virtual desktops should be laid out into
@@ -135,8 +134,8 @@ public:
      */
     quint32 rows() const;
 
-    operator org_kde_plasma_virtual_desktop_management*();
-    operator org_kde_plasma_virtual_desktop_management*() const;
+    operator org_kde_plasma_virtual_desktop_management *();
+    operator org_kde_plasma_virtual_desktop_management *() const;
 
 Q_SIGNALS:
     void removed();
@@ -175,7 +174,7 @@ class KWAYLANDCLIENT_EXPORT PlasmaVirtualDesktop : public QObject
 {
     Q_OBJECT
 public:
-    virtual ~PlasmaVirtualDesktop();
+    ~PlasmaVirtualDesktop() override;
 
     /**
      * Setup this PlasmaVirtualDesktop to manage the @p plasmavirtualdesktop.
@@ -225,7 +224,6 @@ public:
      */
     QString id() const;
 
-
     /**
      * @returns User readable name for the desktop.
      */
@@ -239,8 +237,8 @@ public:
      */
     bool isActive() const;
 
-    operator org_kde_plasma_virtual_desktop*();
-    operator org_kde_plasma_virtual_desktop*() const;
+    operator org_kde_plasma_virtual_desktop *();
+    operator org_kde_plasma_virtual_desktop *() const;
 
 Q_SIGNALS:
     /**
@@ -277,7 +275,6 @@ private:
     QScopedPointer<Private> d;
 };
 
-
 }
 }
 
